@@ -1,6 +1,7 @@
-from notebook.utils import url_path_join
+from jupyter_server.utils import url_path_join as ujoin
 
-from . import handler
+from .config import Lmod as LmodConfig
+from .handler import default_handlers, PinsHandler
 
 
 def _jupyter_server_extension_paths():
@@ -24,8 +25,14 @@ def load_jupyter_server_extension(nbapp):
         nbapp : handle to the Notebook webserver instance.
     """
     nbapp.log.info("Loading lmod extension")
+    lmod_config = LmodConfig(parent=nbapp)
+    launcher_pins = lmod_config.launcher_pins
+
     web_app = nbapp.web_app
-    host_pattern = ".*$"
-    for path, class_ in handler.default_handlers:
-        route_pattern = url_path_join(web_app.settings["base_url"], path)
-        web_app.add_handlers(host_pattern, [(route_pattern, class_)])
+    base_url = web_app.settings["base_url"]
+    for path, class_ in default_handlers:
+        web_app.add_handlers(".*$", [(ujoin(base_url, path), class_)])
+
+    web_app.add_handlers(".*$", [
+        (ujoin(base_url, 'lmod/launcher-pins'), PinsHandler, {'launcher_pins': launcher_pins}),
+    ])
